// -*- C++ -*-
#include "orbsvcs/Security/Security_Current_Impl.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO::Security::Current_Impl::~Current_Impl ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
